+ Run ``run_standard_header_process.py -o https://raw.github.com/mwcraig/feder-object-list/master/feder_object_list.csv --dest-root . --scripts-only /Volumes/Data/upload/2014-04-21``
+ Really want destination to be a named directory, not ``.`` -- no, really need to make the destination directory then run use dest_root as ``.`` so that the script can be re-run if needed.
+ ``bash header_process_script.sh``
+ Either everything succeeded, or...
